searchData={"items":[{"type":"module","title":"Trieval","doc":"Trieval provides an interface for creating and managing trie data structures. A trie, also known as a prefix tree, is a type of search tree used to store associative data structures.\n\nThis module provides functions to create new tries, insert values, and perform various operations on the trie. It supports creating tries from binaries, lists of binaries, and tuples of binaries.","ref":"Trieval.html"},{"type":"function","title":"Trieval.contains?/2","doc":"Returns whether or not a trie contains a given binary key.","ref":"Trieval.html#contains?/2"},{"type":"function","title":"Examples - Trieval.contains?/2","doc":"iex> Trieval.new(~w/apple apply ape ample/) |> Trieval.contains?(\"apple\")\n    true\n\n    iex> Trieval.new(~w/apple apply ape ample/) |> Trieval.contains?(\"zebra\")\n    false","ref":"Trieval.html#contains?/2-examples"},{"type":"function","title":"Trieval.insert/2","doc":"Inserts a binary, list of binaries or tuple of binaries into an existing trie.","ref":"Trieval.html#insert/2"},{"type":"function","title":"Examples - Trieval.insert/2","doc":"iex> Trieval.new() |> Trieval.insert(\"apple\")\n    %Trieval.Trie{trie: %{97 => %{112 => %{112 => %{108 => %{101 => %{mark: :mark}}}}}}}\n\n    Trieval.new(~w/apple apply ape ample/) |> Trieval.insert(~w/zebra corgi/)\n    %Trieval.Trie{trie: %{...}}","ref":"Trieval.html#insert/2-examples"},{"type":"function","title":"Trieval.longest_common_prefix/2","doc":"Collects all binaries that begin with a given prefix. Returns matching binaries, along\nwith matching binaries' longest common prefix. Example use-case would be for auto-completion.","ref":"Trieval.html#longest_common_prefix/2"},{"type":"function","title":"Examples - Trieval.longest_common_prefix/2","doc":"iex> Trieval.new(~w/apple apply ape/) |> Trieval.longest_common_prefix(\"a\")\n    {\"ap\", [\"ape\", \"apple\", \"apply\"]}\n\n    iex> Trieval.new(~w/apple apply ape ample/) |> Trieval.longest_common_prefix(\"z\")\n    {nil, []}","ref":"Trieval.html#longest_common_prefix/2-examples"},{"type":"function","title":"Trieval.new/0","doc":"Returns a new trie. Providing no arguments creates an empty trie.\nOptionally, a binary, a list of binaries or a tuple of binaries can be passed to `new/1`.","ref":"Trieval.html#new/0"},{"type":"function","title":"Examples - Trieval.new/0","doc":"iex> Trieval.new()\n    %Trieval.Trie{trie: %{}}","ref":"Trieval.html#new/0-examples"},{"type":"function","title":"Trieval.new/1","doc":"Returns a new trie containing lists of binaries representing the provided values passed to `new/1`.\nOptional values are a binary, a list of binaries or a tuple of binaries can be passed to `new/1`.","ref":"Trieval.html#new/1"},{"type":"function","title":"Examples - Trieval.new/1","doc":"iex> Trieval.new(\"apple\")\n    %Trieval.Trie{trie: %{97 => %{112 => %{112 => %{108 => %{101 => %{mark: :mark}}}}}}}\n\n    iex> Trieval.new(~w/apple apply ape ample/)\n    %Trieval.Trie{\n              trie: %{\n                97 => %{\n                  109 => %{112 => %{108 => %{101 => %{mark: :mark}}}},\n                  112 => %{\n                    101 => %{mark: :mark},\n                    112 => %{\n                      108 => %{\n                        101 => %{mark: :mark},\n                        121 => %{mark: :mark}\n                      }\n                    }\n                  }\n                }\n              }\n            }","ref":"Trieval.html#new/1-examples"},{"type":"function","title":"Trieval.pattern/2","doc":"Collects all binaries match a given pattern. Returns either a list of matches\nor an error in the form `{:error, reason}`.","ref":"Trieval.html#pattern/2"},{"type":"function","title":"Patterns - Trieval.pattern/2","doc":"`*`      - Wildcard, matches any character.\n\n     `[...]`  - Inclusion group, matches any character between brackets.\n\n     `[^...]` - Exclusion group, matches any character not between brackets.\n\n     `{...}`  - Capture group, must be named and can be combined with an\n                inclusion or exclusion group, otherwise treated as a wildcard.\n                All future instances of same name captures are swapped with\n                the value of the initial capture.","ref":"Trieval.html#pattern/2-patterns"},{"type":"function","title":"Examples - Trieval.pattern/2","doc":"iex> Trieval.new(~w/apple apply ape ample/) |> Trieval.pattern(\"a{1}{1}**\")\n    [\"apple\", \"apply\"]\n\n    iex> Trieval.new(~w/apple apply ape ample/) |> Trieval.pattern(\"*{1[^p]}{1}**\")\n    []\n\n    iex> Trieval.new(~w/apple apply zebra house/) |> Trieval.pattern(\"[hz]****\")\n    [\"house\", \"zebra\"]\n\n    iex> Trieval.new(~w/apple apply zebra house/) |> Trieval.pattern(\"[hz]***[^ea]\")\n    []\n\n    iex> Trieval.new(~w/apple apply zebra house/) |> Trieval.pattern(\"[hz]***[^ea\")\n    {:error, \"Dangling group (exclusion) starting at column 8, expecting ]\"}","ref":"Trieval.html#pattern/2-examples"},{"type":"function","title":"Trieval.prefix/2","doc":"Collects all binaries that begin with a given prefix.","ref":"Trieval.html#prefix/2"},{"type":"function","title":"Examples - Trieval.prefix/2","doc":"iex> Trieval.new(~w/apple apply ape ample/) |> Trieval.prefix(\"ap\")\n    [\"ape\", \"apple\", \"apply\"]\n\n    iex> Trieval.new(~w/apple apply ape ample/) |> Trieval.prefix(\"z\")\n    []","ref":"Trieval.html#prefix/2-examples"},{"type":"module","title":"Trieval.PatternParser","doc":"Parses and verifies patterns that can be matched against the trie data structure.","ref":"Trieval.PatternParser.html"},{"type":"function","title":"Trieval.PatternParser.parse/1","doc":"","ref":"Trieval.PatternParser.html#parse/1"},{"type":"function","title":"Trieval.PatternParser.parse/3","doc":"","ref":"Trieval.PatternParser.html#parse/3"},{"type":"module","title":"Trieval.Trie","doc":"A tiny struct to encapsulate a trie.","ref":"Trieval.Trie.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}